# Read Me
## 1. Introduction
Hi, this is the team from Shinoda.Lab@TokyoTech.
Our team joined the DVU challenge last year during the ICMI workshop. ([Our Last Year's Work [1]](#LastYear))


For the coming DVU2021, we would like to share some resources that might be useful for anyone interested in this challenge.

This package includes a subset from [HLVU [2]](#HLVU) dataset and our annotations (speech and person/face bounding box) for this subset. The following three sections describe their details.

##### Directory Structure

	.
	├── Face
	│   ├── honey_cut_13.txt
	│   ├── huckleberryFinn_cut_12.txt
	│   ├── nuclearFamily_cut_1.txt
	│   ├── spiritualContact_cut_11.txt
	│   ├── superHero_cut_2.txt
	│   └── valkaama_cut_4.txt
	├── Person
	│   ├── honey_cut_13.txt
	│   ├── huckleberryFinn_cut_12.txt
	│   ├── nuclearFamily_cut_1.txt
	│   ├── spiritualContact_cut_11.txt
	│   ├── superHero_cut_2.txt
	│   └── valkaama_cut_4.txt
	├── README.md
	└── Speech
	    └── transcription_with_speaker.xlsx



## 2. A Subset from HLVU Dataset
Because annotating whole movies is time-consuming, we select only one short movie cut (up to 10 min) from each movie.
To select the most informative cuts, we follow the actions/events definition files provided in the HLVU dataset.
You can find these Actions/events definition from `#HLVU Root# > dev.data > #MovieName# > #MovieName#.actions.events.txt`

The cuts we select for each movie are as follows:

| Movie Name       | Cut Number  | Timestamp (Start; End) |
|------------------|------------|------------------------|
| honey            | cut_13     | 01:06:41; 01:09:35     |
| huckleberryFinn  | cut_12     | 01:08:30; 01:17:48     |
| nuclearFamily    | cut_1      | 00:02:47; 00:03:30     |
| spiritualContact | cut_11     | 00:37:03; 00:42:17     |
| superHero        | cut_2      | 00:02:17; 00:03:40     |
| valkaama         | cut_4      | 00:53:46; 00:58:07     |

We segment these cuts from whole movies by [`FFmpeg` [3]](#FFmpeg):

	ffmpeg -i ./Movies/honey.mp4 -ss 01:06:41 -to 01:09:35 -c copy ./Movies/honey/honey_cut_13.mp4

The subset contains six cuts in total, about 24 minutes.

##  3. Speech Annotation
### 3.1 Annotation Workflow
The followings are steps we do to make the speech transcriptions.

1. We use a Youtube [ASR [4]](#ASR) on the original full movie to get transcriptions and timestamps of each utterance;
2. We watch the movie cuts in the subset, then correct these transcriptions and their corresponding speaker IDs.

We export speech annotations as an Excel file. 

###  3.2 Annotation Format
An example record in the Excel file is as follows:

| SRT                                        | Speaker ID  | Correction                                  | S | D | I | C | N |
|--------------------------------------------|-------------|---------------------------------------------|---|---|---|---|---|
| 18                                         |             |                                             |   |   |   |   |   |
| 00:02:29,890 -->   00:02:40,350            |             |                                             |   |   |   |   |   |
| Charlie Luthor should I send a   note home | Ms. Johnson | Charlie, Luthor,  should I send a note home |   |   |   | 8 | 8 |
|                                            |             |                                             |   |   |   |   |   |
| 19                                         |             |                                             |   |   |   |   |   |
| 00:02:32,380 -->   00:02:40,350            |             |                                             |   |   |   |   |   |
| to your parents again no I'm   sorry no    | Ms. Johnson | To your parents again                       |   |   |   | 4 | 4 |
|                                            | Charlie     | No                                          |   |   |   | 1 | 1 |
|                                            | Ms. Johnson | I'm sorry?                                  |   |   |   | 2 | 2 |
|                                            | Charlie     | No                                          |   |   |   | 1 | 1 |

#### ASR Output Part:

- `SRT`:	Outputs from ASR;
- `18`:	The index of utterance in the full movie;
- `00:02:29,890 -->   00:02:40,350`: 	start and end timestamp of an utterance;
- `Charlie Luthor should I send a   note home `:	Transcriptions from ASR. It doesn't contain punctuation marks. It may contain a part of a sentence or multiple sentences.

#### Annotation Part:

- `Speaker ID`:	Speaker ID for the transcriptions. These IDs are consistent with the chracter ID defined in the HLVU; dataset. You can find  chracter ID defination from `#HLVU Root# > dev.data > #MovieName# > #MovieName#.entity.types.txt`;
- `Correction`:	Transcriptions with manual correction. We segment transcriptions by sentence with punctuation marks.


- `S`:	The number of substitutions;
- `D`:	The number of deletions;
- `I`:	The number of insertions;
- `C`:	The number of correct words;
- `N`:	The number of words in the reference (N=S+D+C);
- `WER` = (`S` + `D` + `I` ) / `N`.


## 4. Person/Face Detection Annotation
### 4.1 Annotation Workflow

Person/face detection is annotated frame-by-frame for all six cuts in the subset.
Considering the redundancy in video frames, we performed a sampling before our annotations.

The annotation workflow contains three steps:

1. We sample frames at sampling a rate of 1:100 (every 100th frame is selected) for each movie cut by [`OpenCV` [5]](#OpenCV);
2. We manually label all person and face bounding boxes for each frame;
3. We manually label a person ID for each person and face extracted in Step.2.

We export our annotations as text files. Persons and faces annotations are saved into different directories.

### 4.2 Annotation Format
Some example records in the Excel file is as follows:

	00200.png; 0; 554 43 640 285; Stephanie; 
	00200.png; 1; 0 38 289 360; Jeremy; 
	00200.png; 2; 317 75 506 270; Charlie; 
	00200.png; 3; 222 61 348 312; NULL; 

- `00200.png`:	Frame Index. If a frame doesn't contain any face or person, it will not be listed here;
- `0`:	Instance Index. One frame may contain one or more persons or faces. It starts from 0;
- `554 43 640 285`: `[x1, y1, x2, y2]`: The bounding box of a person or a face;
- `Stephanie`: 	Character ID for a person or a face. These IDs are consistent with the character ID defined in the HLVU; dataset. You can find character ID definition from `#HLVU Root# > dev.data > #MovieName# > #MovieName#.entity.types.txt`;

### Reference

1. <a name="LastYear"></a>
Lu, Yang, et al. "Deep Video Understanding of Character Relationships in Movies." Companion Publication of the 2020 International Conference on Multimodal Interaction. 2020. https://dl.acm.org/doi/10.1145/3395035.3425639

2. <a name="HLVU"></a> 
Curtis, Keith, et al. "HLVU: A new challenge to test deep understanding of movies the way humans do." Proceedings of the 2020 International Conference on Multimedia Retrieval. 2020. https://dl.acm.org/doi/abs/10.1145/3372278.3390742

3. <a name="FFnpeg"></a>
FFmpeg: https://www.ffmpeg.org/

4. <a name="ASR"></a>
Harrenstien, Ken. "Automatic captions in YouTube." The Official Google Blog 11 (2009). https://publicpolicy.googleblog.com/2009/11/automatic-captions-on-youtube.html

5. <a name="OpenCV"></a>
OpenCV: https://opencv.org/


## Contact Us
If you have any questions or suggestions about our annotations, please feel free to contact us.
Email: <yang@ks.cs.titech.ac.jp> (Lu Yang)
